@@ -336,6 +336,7 @@ class SSHClient (ClosingContextManager):
         if banner_timeout is not None:
             t.banner_timeout = banner_timeout
         t.start_client(timeout=timeout)
+        t.set_sshclient(self)
         ResourceManager.register(self, t)
 
         server_key = t.get_remote_server_key()
@@ -464,7 +465,6 @@ class SSHClient (ClosingContextManager):
         """
         chan = self._transport.open_session()
         chan.get_pty(term, width, height, width_pixels, height_pixels)
-        chan.update_environment_variables(environment or {})
         chan.invoke_shell()
         return chan
 
