@@ -40,10 +40,10 @@ This module provides GSS-API / SSPI Key Exchange as defined in :rfc:`4462`.
 import os
 from hashlib import sha1
 
-from paramiko.common import DEBUG, max_byte, zero_byte
+from paramiko.common import *
 from paramiko import util
 from paramiko.message import Message
-from paramiko.py3compat import byte_chr, byte_mask, byte_ord
+from paramiko.py3compat import byte_chr, long, byte_mask, byte_ord
 from paramiko.ssh_exception import SSHException
 
 
